# Security Policy

## Supported Versions

As this package is still in development only the newest version will receive security updates.


## Reporting a Vulnerability

For found vulnerabilities please open an issue on GitHub.
